#!/bin/bash
#
# Sources location : http://www.cmake.org, see the $url for details 
#
# previous packager : P.R. Faasse (p.faase1@chello.nl)
# present packager  : Patrick Smith (BandiPat)
#
# Update history:
# ---------------
# (20-jan-2008) new packager: p.r. faasse (p.faase1@chello.nl)
#               added: this update history, the buildlog generation, 
#               requiredbuilder and .src file generation (52.1 build)
#               taken over from: gmg (gerard.monpontet@orange.fr).
# (07-mai-2008) update to version 2.6.0
# (27-sep-2008) update to version 2.6.2
# (29-sep-2008) some bug-fixes in the gui part, thanks to 'Gapan'
# (29-sep-2008) test with two packages: cmake (non-gui) & cmake-gui
# (01-oct-2008) 
#

#------------------Set Some Variables

soft="cmake"
gsoft="cmake-gui"

softversion="2.8.0"
packageversion="64.1"

# lonesome hook for a buildlog
(

arch="i686"
cpu="i486"
buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"

package="$soft-$softversion-$arch-$packageversion"
gpackage="$gsoft-$softversion-$arch-$packageversion"

dest="$buildir/$package"
gdest="$buildir/$gpackage"

url="http://www.cmake.org/files/v2.8/cmake-$softversion.tar.gz"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xf $srcpkg
rm -f $dest.tgz

rm -rf $dest
mkdir -p $dest/install

rm -rf $gdest
mkdir -p $gdest/install

#-----------------Make the slack-desc files
#
# BipBip-Spaces-String ;-) :-)
#
# makes the '|' of the handy-ruler aligned with the name
# regardless of the actual package name string...
# packages-rulez !
#
BBSS=`echo $soft | sed "s/./ /g"`

cat << EOF > $dest/install/slack-desc
$BBSS|-----handy-ruler------------------------------------------------------|
$soft: CMake (CMake, the cross-platform, open-source make system)
$soft:
$soft: CMake is used to control the software process using simple platform
$soft: and compiler independed configuration files. CMake generates native
$soft: makefiles and workspaces that can be used in the compiler environment
$soft: of your choice.
$soft:
$soft: 
$soft:
$soft:
$soft:
EOF

BBSST=`echo $gsoft | sed "s/./ /g"`

cat << EOF > $gdest/install/slack-desc
$BBSST|-----handy-ruler------------------------------------------------------|
$gsoft: Cmake-gui is the package with the Qt4 gui for Cmake
$gsoft:
$gsoft: CMake is used to control the software process using simple platform
$gsoft: and compiler independed configuration files. CMake generates native
$gsoft: makefiles and workspaces that can be used in the compiler environment
$gsoft: of your choice.
$gsoft:
$gsoft: 
$gsoft: 
$gsoft:
$gsoft:
EOF

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./bootstrap \
  --prefix=/usr \
  --mandir=/man \
  --qt-qmake=/usr/lib/qt/bin/qmake \
  --qt-gui \
  --docdir=/doc/$soft-$softversion

make
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

gzip -9 $dest/usr/man/*/*

#-------------------fix some package-rules bugs:

(
 cd $dest/usr/share/applications/
 sed -i "s/Icon\=CMakeSetup\.png/Icon=CMakeSetup/" CMake.desktop
)
(
 cd $dest/usr/share
 #
 mkdir -p icons/hicolor/32x32/apps
 mv pixmaps/CMakeSetup.png icons/hicolor/32x32/apps/
 #
 mkdir -p icons/hicolor/48x48/apps/
 convert -resize 48x48 icons/hicolor/32x32/apps/CMakeSetup.png icons/hicolor/48x48/apps/CMakeSetup.png
 #
 rmdir pixmaps
)

#-------------------split the actual files of the package into cmake & cmake-gui

(
 cd $dest
 #
 mkdir -p $gdest/usr/bin
 mv usr/bin/cmake-gui $gdest/usr/bin/
 #
 mkdir -p $gdest/usr/share
 mv usr/share/applications $gdest/usr/share/
 mv usr/share/icons        $gdest/usr/share/
 mv usr/share/mime         $gdest/usr/share/
 #
)

#-------------------update the mime database:

mkdir -p $dest/install

cat >>$gdest/install/doinst.sh <<"EOF"
# update mime-database:
usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1

# update the mime-desktop-database
usr/bin/update-desktop-database > /dev/null 2>&1
EOF

#-------------------Add documentation files:

cp -a \
   ChangeLog.manual ChangeLog.txt Readme.txt \
  $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

mkdir -p $gdest/usr/src/$gsoft-$softversion
cp -a $buildir/build-$soft.sh $gdest/usr/src/$gsoft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -p -l y -c n $dest.tlz
cd $buildir
#
# the checksum
#
md5sum $package.tlz >$package.md5
#
# the dependencies generation
#
depfinder -f $package.tlz >$package.dep

#
# produce the file src
#
echo http://zenwalk.pinguix.com/user-accounts/BandiPat/source/build-files/build-cmake.sh > $package.src
echo $url >> $package.src

cd $gdest
makepkg -p -l y -c n $gdest.tlz
cd $buildir
#
# the checksum
#
md5sum $gpackage.tlz >$gpackage.md5
#
# the dependencies generation
#
ADD="cmake" depfinder -f $gpackage.tlz >$gpackage.dep

) 2>&1 | tee "$soft-$softversion.txt"
